@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: asn1-encoding
 version: 0.9.3
-id: asn1-encoding-0.9.3-973a6b8f38afc857f3a60ad311c8ee45
-key: asn1e_A0jeMIoYyiZ4PSPkybrUpF
+id: asn1-encoding-0.9.3-fec344bb54bb5da4bfe7deb0a3562b73
+key: asn1e_AWULG2H3g6SCee0eL9dbv9
 license: BSD3
 copyright: Vincent Hanquez <vincent@snarc.org>
 maintainer: vincent@snarc.org
@@ -26,9 +26,9 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/asn1-encoding-0.9.3
 library-dirs: /usr/lib/ghc-7.10.3/site-local/asn1-encoding-0.9.3
 data-dir: /usr/share/arm-linux-ghc-7.10.3/asn1-encoding-0.9.3
-hs-libraries: HSasn1-encoding-0.9.3-A0jeMIoYyiZ4PSPkybrUpF
+hs-libraries: HSasn1-encoding-0.9.3-AWULG2H3g6SCee0eL9dbv9
 depends:
-    asn1-types-0.3.2-3969820adc8283f126affe054010f830
+    asn1-types-0.3.2-0a9b49f98bdd53624b82b3c86ed41efa
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
     hourglass-0.2.10-b11bcf654d7049575fb45d24076b832b
